@@ -1,6 +1,7 @@
-use crate::FuturesTypes;
 use serde::{Deserialize, Serialize};
 
+use crate::FuturesTypes;
+
 #[derive(Debug, Clone, Copy, Default, Serialize, Deserialize)]
 /// Describes the position information of the account
 pub struct Position {
@@ -128,7 +129,7 @@ impl Position {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::round;
+    use crate::utils::round;
 
     #[test]
     fn position_change_size() {
